@@ -34,6 +34,9 @@ debci_mirror=${debci_mirror:-}
 debci_backend=${debci_backend:-schroot}
 debci_data_basedir=${debci_data_basedir:-$(readlink -f "${debci_base_dir}/data")}
 debci_quiet="${debci_quiet:-false}"
+debci_sendmail_from="${debci_sendmail_from:-Debian Continuous Integration <owner@localhost>}"
+debci_sendmail_to="${debci_sendmail_to:-%s@localhost}"
+debci_url_base="${debci_url_base:-http://localhost:8888}"
 
 shared_short_options='c:s:a:b:d:hq'
 shared_long_options='config:,suite:,arch:,backend:,data-dir:,help,quiet'
@@ -54,7 +57,8 @@ usage_shared_options="Common options:
   --help                    show this usage message
 "
 
-TEMP=`getopt -o ${shared_short_options}${short_options:-} --long ${shared_long_options},${long_options:-} -- "$@"`
+program_name=${0##*/}
+TEMP=`getopt --name $program_name -o ${shared_short_options}${short_options:-} --long ${shared_long_options},${long_options:-} -- "$@"`
 
 if [ $? != 0 ]; then
   exit 1
