@@ -134,19 +134,36 @@ jQuery(function($) {
       });
 
       $('#package-select').hide();
+
+      if ($('#package-search').val() != '') {
+        // trigger search immediately if there is something in the search box
+        // already
+        $('#package-search').keyup();
+      }
     });
+
+    if (window.location.search.match(/\?q=/)) {
+      var query_string = window.location.search.replace(/^\?/, '').split('&');
+      for (var i = 0; i < query_string.length; i++) {
+        var parts = query_string[i].split('=');
+        var key = parts[0];
+        if (key == 'q') {
+          var value = decodeURIComponent(parts[1]);
+          $('#package-search').val(value);
+        }
+      }
+    }
   });
 
   $('#package-search').keyup(function() {
       var query = $(this).val();
-      var MAX_ITEMS = 13;
 
       if (query.length > 0) {
         $('.request-search').hide();
         $('#package-select').show();
         var found = 0;
         $('#package-select li').each(function() {
-          if ($(this).attr('data-package').match(query) && found <= MAX_ITEMS) {
+          if ($(this).attr('data-package').match(query)) {
             $(this).show();
             found++;
           } else {
@@ -167,6 +184,8 @@ jQuery(function($) {
         $('.search-count').hide();
         $('#package-select li').hide();
       }
+
+      window.history.replaceState({}, '', '?q=' + encodeURIComponent(query));
   });
 
   if (window.location.pathname == '/') {
