@@ -17,12 +17,13 @@ rake
 EOF
   export debci_data_basedir="$__tmpdir/data"
   export debci_config_dir="$__tmpdir/config"
+  export debci_arch=$(dpkg --print-architecture)
 }
 
 status_dir_for_package() {
   local pkg="$1"
   pkg_dir=$(echo "$pkg" | sed -e 's/\(\(lib\)\?.\).*/\1\/&/')
-  echo "${debci_data_basedir}/packages/unstable/amd64/${pkg_dir}"
+  echo "${debci_data_basedir}/packages/unstable/${debci_arch}/${pkg_dir}"
 }
 
 tearDown() {
